/*
	$Id: CountryComboBox.cpp 1226 2018-11-30 16:10:42Z john $

	This file is part of the 4c LDAP library.

	The 4c LDAP library is Copyright (c) 2018, The 4c Company.

	The 4c LDAP library is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The 4c LDAP library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <ldap4cUIComponents/CountryComboBox.h>

#include <ldap4c/Directory.h>
#include <ldap4c/Exception.h>

using namespace Ldap4cUIComponents;

CountryComboBox::CountryComboBox( QWidget* pparent /*= NULL*/ )
	: QComboBox( pparent )
{
	connect( this, SIGNAL( activated(int) ), this, SLOT( onActivated(int) ) );
}

CountryComboBox::~CountryComboBox()
{
}

void CountryComboBox::populate()
{
	clear();

	const Ldap4c::countryMap groupS( Ldap4c::Directory::countrys() );
	for( Ldap4c::countryMap::const_iterator it = groupS.begin();
			it != groupS.end();
			++it )
	{
		const Ldap4c::country& group( it->second );
		addItem( QString::fromStdString( group.description() ), QString::fromStdString( group.dn().dn() ) );
	}
}

const Ldap4c::country& CountryComboBox::currentItem()
{
	int nIdx = currentIndex();

	if( -1 == nIdx )
	{
		throw Ldap4c::Exception( __FILE__, __LINE__, Ldap4c::LDX_NOGROUPOFNAMESSELECTED );
	}

	std::string strDn( itemData( nIdx ).toString().toStdString() );
	Ldap4c::Base::Dn dn( strDn );
	Ldap4c::countryMap::const_iterator it = Ldap4c::Directory::countrys().find( dn );
	if( Ldap4c::Directory::countrys().end() == it )
	{
		throw Ldap4c::Exception( __FILE__, __LINE__, Ldap4c::LDX_NOSUCHGROUPOFNAMES, false, dn.dn() );
	}

	return it->second;
}

void CountryComboBox::setCurrentItem(const Ldap4c::country& ctry )
{
	int nIndex = findData( QString::fromStdString( ctry.dn().dn() ) );
	setCurrentIndex( nIndex );
}

void CountryComboBox::onActivated( int nCurrentIndex )
{
	if( -1 != nCurrentIndex )
	{
		std::string strDn( itemData( nCurrentIndex ).toString().toStdString() );
		Ldap4c::Base::Dn dn( strDn );
		Ldap4c::countryMap::const_iterator it = Ldap4c::Directory::countrys().find( dn );
		if( Ldap4c::Directory::countrys().end() != it )
		{
			emit activated( it->second );
		}
	}
}
