/*
	$Id: GroupOfNamesComboBox.cpp 1227 2018-12-01 15:28:02Z john $

	This file is part of the 4c LDAP library.

	The 4c LDAP library is Copyright (c) 2018, The 4c Company.

	The 4c LDAP library is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The 4c LDAP library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <ldap4cUIComponents/GroupOfNamesComboBox.h>

#include <ldap4c/Directory.h>
#include <ldap4c/Exception.h>

using namespace Ldap4cUIComponents;

GroupOfNamesComboBox::GroupOfNamesComboBox( QWidget* pparent /*= NULL*/ )
	: QComboBox( pparent )
{
	connect( this, SIGNAL( activated(int) ), this, SLOT( onActivated(int) ) );
}

GroupOfNamesComboBox::~GroupOfNamesComboBox()
{
}

void GroupOfNamesComboBox::populate()
{
	clear();

	const Ldap4c::groupOfNamesMap groupS( Ldap4c::Directory::groupOfNames() );
	for( Ldap4c::groupOfNamesMap::const_iterator it = groupS.begin();
			it != groupS.end();
			++it )
	{
		const Ldap4c::groupOfNames& group( it->second );
		addItem( QString::fromStdString( group.description() ), QString::fromStdString( group.dn().dn() ) );
	}
}

const Ldap4c::groupOfNames& GroupOfNamesComboBox::currentItem()
{
	int nIdx = currentIndex();

	if( -1 == nIdx )
	{
		throw Ldap4c::Exception( __FILE__, __LINE__, Ldap4c::LDX_NOGROUPOFNAMESSELECTED );
	}

	std::string strDn( itemData( nIdx ).toString().toStdString() );
	Ldap4c::Base::Dn dn( strDn );
	Ldap4c::groupOfNamesMap::const_iterator it = Ldap4c::Directory::groupOfNames().find( dn );
	if( Ldap4c::Directory::groupOfNames().end() == it )
	{
		throw Ldap4c::Exception( __FILE__, __LINE__, Ldap4c::LDX_NOSUCHGROUPOFNAMES, false, dn.dn() );
	}

	return it->second;
}

void GroupOfNamesComboBox::setCurrentItem( const Ldap4c::groupOfNames& group )
{
	int nIndex = findData( QString::fromStdString( group.dn().dn() ) );
	setCurrentIndex( nIndex );
}

void GroupOfNamesComboBox::onActivated( int nCurrentIndex )
{
	if( -1 != nCurrentIndex )
	{
		std::string strDn( itemData( nCurrentIndex ).toString().toStdString() );
		Ldap4c::Base::Dn dn( strDn );
		Ldap4c::groupOfNamesMap::const_iterator it = Ldap4c::Directory::groupOfNames().find( dn );
		if( Ldap4c::Directory::groupOfNames().end() != it )
		{
			emit activated( it->second );
		}
	}
}
