/*
	$Id: GroupWidget.cpp 1231 2018-12-01 19:46:23Z john $

	This file is part of the 4c LDAP library.

	The 4c LDAP library is Copyright (c) 2018, The 4c Company.

	The 4c LDAP library is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The 4c LDAP library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <ldap4cUIComponents/GroupWidget.h>
#include "ui_GroupWidget.h"

#include <ldap4cUIComponents/InetOrgPersonDialog.h>
#include <ldap4cUIComponents/InetOrgPersonListWidgetItem.h>

#include <ldap4c/Directory.h>

#include <QMenu>
#include <QCursor>

using namespace Ldap4cUIComponents;

GroupWidget::GroupWidget(QWidget *parent) :
	QWidget(parent),
	ui(new Ui::GroupWidget)
{
	ui->setupUi(this);

	ui->_pcbxGroup->populate();

	connect( ui->_pcbxGroup, SIGNAL(activated(Ldap4c::groupOfNames)), this, SLOT(onActivatedGroupOfNamesComboBox(Ldap4c::groupOfNames)) );
	connect( ui->_plstMember, SIGNAL(itemActivated(Ldap4c::inetOrgPerson)), this, SLOT(onItemActivated(Ldap4c::inetOrgPerson)) );
	connect( ui->_plstMember, SIGNAL(itemClicked(Ldap4c::inetOrgPerson)), this, SLOT(onItemClicked(Ldap4c::inetOrgPerson)) );
	connect( ui->_plstMember, SIGNAL(itemDoubleClicked(Ldap4c::inetOrgPerson)), this, SLOT(onItemDoubleClicked(Ldap4c::inetOrgPerson)) );

	onToggledGroupCheckBox( false );
}

GroupWidget::~GroupWidget()
{
	delete ui;
}

void GroupWidget::onActivatedGroupOfNamesComboBox( const Ldap4c::groupOfNames& group )
{
	ui->_plstMember->populate( group.member() );
}

void GroupWidget::onToggledGroupCheckBox( bool bOn )
{
	ui->_pcbxGroup->setEnabled( bOn );

	if( bOn )
	{
		try
		{
			const Ldap4c::groupOfNames& group( ui->_pcbxGroup->currentItem() );
			onActivatedGroupOfNamesComboBox( group );
		}
		catch( ... )
		{
		}
	}
	else
	{
		ui->_plstMember->populate( Ldap4c::Directory::inetOrgPersons() );
	}
}

void GroupWidget::onItemActivated( const Ldap4c::inetOrgPerson& person )
{
	emit inetOrgPersonActivated( person );
}

void GroupWidget::onItemClicked( const Ldap4c::inetOrgPerson& person )
{
	emit inetOrgPersonClicked( person );
}

void GroupWidget::onItemDoubleClicked( const Ldap4c::inetOrgPerson& person )
{
	emit inetOrgPersonDoubleClicked( person );

	InetOrgPersonDialog dlg( this, person );
	dlg.exec();
}

void GroupWidget::onCMReqMember( const QPoint& pt )
{
	QMenu mnu;
	QAction* pactShow = mnu.addAction( "Open" );
	QAction* pactNew = mnu.addAction( "New" );

	QAction* pactDone = mnu.exec( QCursor::pos() );
	if( NULL != pactDone )
	{
		if( pactShow == pactDone )
		{
			QListWidgetItem* pitem = ui->_plstMember->itemAt( pt );
			if( NULL != pitem )
			{
				InetOrgPersonListWidgetItem* pitemReal = dynamic_cast<InetOrgPersonListWidgetItem*>( pitem );
				if( NULL != pitemReal )
				{
					InetOrgPersonDialog dlg( this, pitemReal->inetOrgPerson() );
					dlg.exec();
				}
			}
		}
		else if( pactNew == pactDone )
		{
			InetOrgPersonDialog dlg( this );
			dlg.exec();
		}

		onToggledGroupCheckBox( ui->_pchkGroup->isChecked() );
	}
}
