/*
	$Id: InetOrgPersonDialog.cpp 1237 2018-12-02 15:36:11Z john $

	This file is part of the 4c LDAP library.

	The 4c LDAP library is Copyright (c) 2018, The 4c Company.

	The 4c LDAP library is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The 4c LDAP library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <ldap4cUIComponents/InetOrgPersonDialog.h>
#include "ui_InetOrgPersonDialog.h"

#include <ldap4c/Directory.h>
#include <ldap4c/Exception.h>

#include <Base4c/Util.h>

#include <QMessageBox>

using namespace Ldap4cUIComponents;

InetOrgPersonDialog::InetOrgPersonDialog( QWidget *parent, Ldap4c::inetOrgPerson person )
	: QDialog(parent),
	ui(new Ui::InetOrgPersonDialog),
	_bCreate( false )
{
	ui->setupUi(this);

	if( !person.dn().dn().length() )
	{
		_bCreate = true;
	}

	ui->_pwdgPerson->givenName()->setText( QString::fromStdString( person.givenName() ) );
	ui->_pwdgPerson->sn()->setText( QString::fromStdString( person.sn() ) );
	ui->_pwdgPerson->dn()->setText( QString::fromStdString( person.dn().dn() ) );
	ui->_pwdgPerson->displayName()->setText( QString::fromStdString( person.displayName() ) );
	ui->_pwdgPerson->initials()->setText( QString::fromStdString( person.initials() ) );
	ui->_pwdgPerson->o()->setText( QString::fromStdString( person.o() ) );
	ui->_pwdgPerson->title()->setText( QString::fromStdString( person.title() ) );
	ui->_pwdgContact->telephoneNumber()->setText( QString::fromStdString( person.telephoneNumber() ) );
	ui->_pwdgContact->homePhone()->setText( QString::fromStdString( person.homePhone() ) );
	ui->_pwdgContact->mobile()->setText( QString::fromStdString( person.mobile() ) );
	if( person.mail().size() )
	{
		QString strMail;
		for( std::set<std::string>::const_iterator itMail = person.mail().begin();
				itMail != person.mail().end();
				++itMail )
		{
			if( person.mail().begin() != itMail )
			{
				strMail += "\n";
			}

			strMail += QString::fromStdString( *itMail );
		}
		ui->_pwdgContact->mail()->setPlainText( strMail );
	}
	ui->_pwdgAddress->street()->setText( QString::fromStdString( person.street() ) );
	ui->_pwdgAddress->l()->setText( QString::fromStdString( person.l() ) );
	ui->_pwdgAddress->st()->setText( QString::fromStdString( person.st() ) );
	ui->_pwdgAddress->postalCode()->setText( QString::fromStdString( person.postalCode() ) );
	try
	{
		const Ldap4c::country& ctry( person.ctry() );
		ui->_pwdgAddress->country()->setCurrentItem( ctry );
	}
	catch( ... )
	{
		ui->_pwdgAddress->country()->setCurrentIndex( -1 );
	}
	ui->_pwdgAddress->homePostalAddress()->setPlainText( QString::fromStdString( person.homePostalAddress() ) );
}

InetOrgPersonDialog::~InetOrgPersonDialog()
{
	delete ui;
}

void InetOrgPersonDialog::accept()
{
	Ldap4c::Base::Dn dn( ui->_pwdgPerson->dn()->text().toStdString() );

	Ldap4c::inetOrgPerson person( dn );
	person.setCn( ui->_pwdgPerson->displayName()->text().toStdString() );
	person.setDisplayName( ui->_pwdgPerson->displayName()->text().toStdString() );
	person.setSn( ui->_pwdgPerson->sn()->text().toStdString() );
	person.setGivenName( ui->_pwdgPerson->givenName()->text().toStdString() );
	person.setInitials( ui->_pwdgPerson->initials()->text().toStdString() );
	person.setO( ui->_pwdgPerson->o()->text().toStdString() );
	person.setTitle( ui->_pwdgPerson->title()->text().toStdString() );
	person.setTelephoneNumber( ui->_pwdgContact->telephoneNumber()->text().toStdString() );
	person.setHomePhone( ui->_pwdgContact->homePhone()->text().toStdString() );
	person.setMobile( ui->_pwdgContact->mobile()->text().toStdString() );
	if( ui->_pwdgContact->mail()->toPlainText().length() )
	{
		std::string strMails( ui->_pwdgContact->mail()->toPlainText().toStdString() );
		Base4c::StringList strMailS = Base4c::tokenize( strMails, '\n' );
		for( Base4c::StringList::const_iterator itMail = strMailS.begin();
				itMail != strMailS.end();
				++itMail )
		{
			person.setMail( *itMail );
		}
	}
	person.setStreet( ui->_pwdgAddress->street()->text().toStdString() );
	person.setL( ui->_pwdgAddress->l()->text().toStdString() );
	person.setSt( ui->_pwdgAddress->st()->text().toStdString() );
	person.setPostalCode( ui->_pwdgAddress->postalCode()->text().toStdString() );
	if( -1 != ui->_pwdgAddress->country()->currentIndex() )
	{
		person.setCtry( ui->_pwdgAddress->country()->currentItem() );
	}

	try
	{
		if( _bCreate )
		{
			Ldap4c::Directory::createInetOrgPerson( Ldap4c::Directory::ldap(), person );
		}
		else
		{
			Ldap4c::Directory::updateInetOrgPerson( Ldap4c::Directory::ldap(), person );
		}
		QDialog::accept();
	}
	catch( const Ldap4c::Exception& e )
	{
		QMessageBox::warning( this, QString::fromStdString( Ldap4c::Exception::explainErrorCode( e.errorCode() ) ), QString::fromStdString( e.legend() ) );
	}
}

void InetOrgPersonDialog::reject()
{
	QDialog::reject();
}
