/*
	$Id: InetOrgPersonListWidget.cpp 1231 2018-12-01 19:46:23Z john $

	This file is part of the 4c LDAP library.

	The 4c LDAP library is Copyright (c) 2018, The 4c Company.

	The 4c LDAP library is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The 4c LDAP library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <ldap4cUIComponents/InetOrgPersonListWidget.h>

#include <ldap4cUIComponents/InetOrgPersonListWidgetItem.h>

using namespace Ldap4cUIComponents;

InetOrgPersonListWidget::InetOrgPersonListWidget( QWidget* pparent /*= NULL */ )
	: QListWidget( pparent )
{
	connect( this, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(onItemActivated(QListWidgetItem*)) );
	connect( this, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(onItemClicked(QListWidgetItem*)) );
	connect( this, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(onItemDoubleClicked(QListWidgetItem*)) );
}

void InetOrgPersonListWidget::populate( const Ldap4c::inetOrgPersonMap& personS )
{
	clear();

	for( Ldap4c::inetOrgPersonMap::const_iterator it = personS.begin();
			it != personS.end();
			++it )
	{
		new InetOrgPersonListWidgetItem( this, it->second );
	}
}

void InetOrgPersonListWidget::populate( const Ldap4c::inetOrgPersonPtrMap& personS )
{
	clear();

	for( Ldap4c::inetOrgPersonPtrMap::const_iterator it = personS.begin();
			it != personS.end();
			++it )
	{
		new InetOrgPersonListWidgetItem( this, *it->second );
	}
}

void InetOrgPersonListWidget::onItemActivated( QListWidgetItem *pitem )
{
	if( NULL != pitem )
	{
		InetOrgPersonListWidgetItem* pitemReal = dynamic_cast<InetOrgPersonListWidgetItem*>( pitem );
		if( NULL != pitemReal )
		{
			const Ldap4c::inetOrgPerson& person( pitemReal->inetOrgPerson() );
			emit itemActivated( person );
		}
	}
}

void InetOrgPersonListWidget::onItemClicked( QListWidgetItem *pitem )
{
	if( NULL != pitem )
	{
		InetOrgPersonListWidgetItem* pitemReal = dynamic_cast<InetOrgPersonListWidgetItem*>( pitem );
		if( NULL != pitemReal )
		{
			const Ldap4c::inetOrgPerson& person( pitemReal->inetOrgPerson() );
			emit itemClicked( person );
		}
	}
}

void InetOrgPersonListWidget::onItemDoubleClicked( QListWidgetItem *pitem )
{
	if( NULL != pitem )
	{
		InetOrgPersonListWidgetItem* pitemReal = dynamic_cast<InetOrgPersonListWidgetItem*>( pitem );
		if( NULL != pitemReal )
		{
			const Ldap4c::inetOrgPerson& person( pitemReal->inetOrgPerson() );
			emit itemDoubleClicked( person );
		}
	}
}
