/*
	$Id: InetOrgPersonWidget.cpp 1233 2018-12-02 13:06:35Z john $

	This file is part of the 4c LDAP library.

	The 4c LDAP library is Copyright (c) 2018, The 4c Company.

	The 4c LDAP library is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The 4c LDAP library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <ldap4cUIComponents/InetOrgPersonWidget.h>

#include <ldap4c/country.h>

#include <algorithm>

using namespace Ldap4cUIComponents;

InetOrgPersonWidget::InetOrgPersonWidget( QWidget* pparent /*= NULL*/ )
	: QTextBrowser( pparent )
{
	setOpenExternalLinks( true );
}

void InetOrgPersonWidget::setInetOrgPerson( const Ldap4c::inetOrgPerson& person )
{
	QString strHtml;

	strHtml  = "<html><head><title>";
	strHtml += QString::fromStdString( person.dn().dn() );
	strHtml += "</title></head>\n";
	strHtml += "<body>\n";

	strHtml += "  <table border=\"0\" cellspacing=\"8\">\n";

	strHtml += "    <tr><td>Display name</td><td>";
	strHtml += QString::fromStdString( person.displayName() );
	strHtml += "</td></tr>\n";

	strHtml += "    <tr><td>Title</td><td>";
	strHtml += QString::fromStdString( person.title() );
	strHtml += "</td></tr>\n";

	strHtml += "    <tr><td>Organization</td><td>";
	strHtml += QString::fromStdString( person.o() );
	strHtml += "</td></tr>\n";

	strHtml += "    <tr><td>Phone</td><td><a href=\"tel:";
	strHtml += QString::fromStdString( person.telephoneNumber() );
	strHtml +="\">";
	strHtml += QString::fromStdString( person.telephoneNumber() );
	strHtml += "</a></td></tr>\n";

	strHtml += "    <tr><td>Home phone</td><td><a href=\"tel:";
	strHtml += QString::fromStdString( person.homePhone() );
	strHtml +="\">";
	strHtml += QString::fromStdString( person.homePhone() );
	strHtml += "</a></td></tr>\n";

	strHtml += "    <tr><td>Mobile</td><td><a href=\"tel:";
	strHtml += QString::fromStdString( person.mobile() );
	strHtml +="\">";
	strHtml += QString::fromStdString( person.mobile() );
	strHtml += "</a></td></tr>\n";

	strHtml += "    <tr><td>email</td><td>";
	const std::set<std::string>& strMailS( person.mail() );
	for( std::set<std::string>::const_iterator itMail = strMailS.begin();
			itMail != strMailS.end();
			++itMail )
	{
		if( itMail != strMailS.begin() )
		{
			strHtml += "<br/>\n";
		}
		strHtml += "<a href=\"mailto:";
		strHtml += QString::fromStdString( *itMail );
		strHtml += "\">";
		strHtml += QString::fromStdString( *itMail );
		strHtml += "</a>";
	}
	strHtml += "</td></tr>\n";

	strHtml += "    <tr><td>Address</td><td>";
	strHtml += "      <table border=\"0\" cellspacing=\"0\">\n";

	std::string strStreet( person.street() );
	replaceAll( strStreet, std::string( "$" ), std::string( "<br>\n" ) );
	strHtml += "        <tr><td>";//street</td><td>";
	strHtml += QString::fromStdString( strStreet );
	strHtml += "</td></tr>\n";

	strHtml += "        <tr><td>";//l</td><td>";
	strHtml += QString::fromStdString( person.l() );
	strHtml += "</td></tr>\n";

	strHtml += "        <tr><td>";//st</td><td>";
	strHtml += QString::fromStdString( person.st() );
	strHtml += "</td></tr>\n";

	strHtml += "        <tr><td>";//postalCode</td><td>";
	strHtml += QString::fromStdString( person.postalCode() );
	strHtml += "</td></tr>\n";

//	strHtml += "        <tr><td>destinationIndicator</td><td>";
//	strHtml += QString::fromStdString( person.destinationIndicator() );
//	strHtml += "</td></tr>\n";

	strHtml += "        <tr><td>";//c</td><td>";
	try
	{
		strHtml += QString::fromStdString( person.ctry().description() );
	}
	catch( ... )
	{
	}
	strHtml += "        </td></tr>\n";
	strHtml += "      </table>\n";
	strHtml += "</td></tr>\n";

	std::string strHomeAddress( person.homePostalAddress() );
	replaceAll( strHomeAddress, std::string( "$" ), std::string( "<br>\n" ) );
	strHtml += "    <tr><td>Home address</td><td>";
	strHtml += QString::fromStdString( strHomeAddress );
	strHtml += "</td></tr>\n";


	strHtml += "  </table>\n";
	strHtml += "</body>";
	strHtml += "</html>";

	setHtml( strHtml );
}

void InetOrgPersonWidget::replaceAll( std::string& str, const std::string& from, const std::string& to )
{
	if(from.empty())
		return;
	size_t start_pos = 0;
	while((start_pos = str.find(from, start_pos)) != std::string::npos)
	{
		str.replace(start_pos, from.length(), to);
		start_pos += to.length(); // In case 'to' contains 'from', like replacing 'x' with 'yx'
	}
}
